/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#ifndef CEPCONTACTSTATE_H
#define CEPCONTACTSTATE_H

#include "WizardState.h"

class CepContactWidget;
// Dependency from cepcoreschema
// Declaration here to avoid declaration in dependant projects.
namespace cepcoreschema {
class Cep;
}

/**
 * @ingroup group_sdk_application_wizard
 *
 * @brief
 * State of the contact of the creator of the CEP
 *
 */
class CepContactState  : public WizardState  {

    Q_OBJECT;

public:
    /**  Constructor */
    CepContactState(QString name, CepContactWidget * widget, WizardMainWindow * mainWidnow, cepcoreschema::Cep * domCep);
    /**  Destructor */
    ~CepContactState();

protected:
    virtual void onEntry( QEvent * event);
    virtual void onExit ( QEvent * event );


private:
    cepcoreschema::Cep * domCep;

};
#endif
